Scroller example - FixedColumns integration

# Scroller example FixedColumns integration

This example shows Scroller operating with FixedColumns. FixedColumns has the ability to "freeze" columns and the left and right of a scrolling table in place. Initialisation is exactly the same as normal and all of the standard options are available for both FixedColumns and Scroller. They will automatically detect if they are being used together.

You may need to resize your browser window to force the table to scroll horizontally with this example!

ID | First name | Last name | ZIP / Post code | Country
--- | --- | --- | --- | ---

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { var table = $('#example').DataTable( { ajax: "../data/2500.txt", deferRender: true, scrollY: 200, scrollX: true, scrollCollapse: true, scroller: true } ); new $.fn.dataTable.FixedColumns( table ); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- //code.jquery.com/jquery-1.12.3.min.js
- ../../../../media/js/jquery.dataTables.js
- ../../../FixedColumns/js/dataTables.fixedColumns.js
- ../../js/dataTables.scroller.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

`/* For this example, force x-scrolling by making the table width smaller */ div.dataTables_wrapper { width: 75%; margin: 0 auto; }`

The following CSS library files are loaded for use in this example to provide the styling of the table:

- ../../../../media/css/jquery.dataTables.css
- ../../../FixedColumns/css/fixedColumns.dataTables.css
- ../../css/scroller.dataTables.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.